Get a description of a data frame
get_text_description.RdGet a description of a data frame
Arguments
- df
a data frame.
- prompt
character. A prompt asking how the data should be described.
- pcdas_token
character. PCDaS API token. If not provided, the function will look for it on renvirom.
- throttle_rate
Rate of requests per second allowed. Defaults to 1 request per second.
- max_tries
Max number of retries before fail. Defaults to 10.
Examples
if (FALSE) { # \dontrun{
prompt <- paste(
"This data contains sepal and petal measurements.",
"Write a small paragraph describing the species."
)
get_text_description(df = iris, prompt = prompt)
} # }